@@ -3,7 +3,7 @@ CREATE TABLE slideshows (
 	name		varchar(255)		DEFAULT ''	NOT NULL,
 	delay		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (slideshowid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE slides (
 	slideid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	slideshowid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -11,7 +11,7 @@ CREATE TABLE slides (
 	step		integer		DEFAULT '0'	NOT NULL,
 	delay		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (slideid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX slides_slides_1 on slides (slideshowid);
 CREATE TABLE drules (
 	druleid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -23,7 +23,7 @@ CREATE TABLE drules (
 	status		integer		DEFAULT '0'	NOT NULL,
 	unique_dcheckid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (druleid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE dchecks (
 	dcheckid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	druleid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -36,7 +36,7 @@ CREATE TABLE dchecks (
 	snmpv3_authpassphrase		varchar(64)		DEFAULT ''	NOT NULL,
 	snmpv3_privpassphrase		varchar(64)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (dcheckid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX dchecks_1 on dchecks (druleid);
 CREATE TABLE dhosts (
 	dhostid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -45,7 +45,7 @@ CREATE TABLE dhosts (
 	lastup		integer		DEFAULT '0'	NOT NULL,
 	lastdown		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (dhostid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX dhosts_1 on dhosts (druleid);
 CREATE TABLE dservices (
 	dserviceid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -60,7 +60,7 @@ CREATE TABLE dservices (
 	dcheckid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	ip		varchar(39)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (dserviceid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE UNIQUE INDEX dservices_1 on dservices (dcheckid,type,key_,ip,port);
 CREATE INDEX dservices_2 on dservices (dhostid);
 CREATE TABLE ids (
@@ -69,7 +69,7 @@ CREATE TABLE ids (
 	field_name		varchar(64)		DEFAULT ''	NOT NULL,
 	nextid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (nodeid,table_name,field_name)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE httptest (
 	httptestid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	name		varchar(64)		DEFAULT ''	NOT NULL,
@@ -89,7 +89,7 @@ CREATE TABLE httptest (
 	http_user		varchar(64)		DEFAULT ''	NOT NULL,
 	http_password		varchar(64)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (httptestid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX httptest_httptest_1 on httptest (applicationid);
 CREATE INDEX httptest_2 on httptest (name);
 CREATE INDEX httptest_3 on httptest (status);
@@ -104,7 +104,7 @@ CREATE TABLE httpstep (
 	required		varchar(255)		DEFAULT ''	NOT NULL,
 	status_codes		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (httpstepid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX httpstep_httpstep_1 on httpstep (httptestid);
 CREATE TABLE httpstepitem (
 	httpstepitemid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -112,7 +112,7 @@ CREATE TABLE httpstepitem (
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	type		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (httpstepitemid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE UNIQUE INDEX httpstepitem_httpstepitem_1 on httpstepitem (httpstepid,itemid);
 CREATE TABLE httptestitem (
 	httptestitemid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -120,7 +120,7 @@ CREATE TABLE httptestitem (
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	type		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (httptestitemid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE UNIQUE INDEX httptestitem_httptestitem_1 on httptestitem (httptestid,itemid);
 CREATE TABLE nodes (
 	nodeid		integer		DEFAULT '0'	NOT NULL,
@@ -133,7 +133,7 @@ CREATE TABLE nodes (
 	nodetype		integer		DEFAULT '0'	NOT NULL,
 	masterid		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (nodeid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE node_cksum (
 	nodeid		integer		DEFAULT '0'	NOT NULL,
 	tablename		varchar(64)		DEFAULT ''	NOT NULL,
@@ -141,8 +141,8 @@ CREATE TABLE node_cksum (
 	cksumtype		integer		DEFAULT '0'	NOT NULL,
 	cksum		text			NOT NULL,
 	sync		char(128)		DEFAULT ''	NOT NULL
-) type=InnoDB;
-CREATE INDEX node_cksum_cksum_1 on node_cksum (nodeid,tablename,recordid,cksumtype);
+) ENGINE=InnoDB;
+CREATE INDEX node_cksum_1 on node_cksum (nodeid,cksumtype,tablename,recordid);
 CREATE TABLE services_times (
 	timeid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	serviceid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -151,7 +151,7 @@ CREATE TABLE services_times (
 	ts_to		integer		DEFAULT '0'	NOT NULL,
 	note		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (timeid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX services_times_times_1 on services_times (serviceid,type,ts_from,ts_to);
 CREATE TABLE alerts (
 	alertid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -170,7 +170,7 @@ CREATE TABLE alerts (
 	esc_step		integer		DEFAULT '0'	NOT NULL,
 	alerttype		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (alertid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX alerts_1 on alerts (actionid);
 CREATE INDEX alerts_2 on alerts (clock);
 CREATE INDEX alerts_3 on alerts (eventid);
@@ -181,7 +181,7 @@ CREATE TABLE history (
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	clock		integer		DEFAULT '0'	NOT NULL,
 	value		double(16,4)		DEFAULT '0.0000'	NOT NULL
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX history_1 on history (itemid,clock);
 CREATE TABLE history_sync (
 	id		bigint unsigned			NOT NULL	auto_increment unique,
@@ -190,13 +190,13 @@ CREATE TABLE history_sync (
 	clock		integer		DEFAULT '0'	NOT NULL,
 	value		double(16,4)		DEFAULT '0.0000'	NOT NULL,
 	PRIMARY KEY (id)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX history_sync_1 on history_sync (nodeid,id);
 CREATE TABLE history_uint (
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	clock		integer		DEFAULT '0'	NOT NULL,
 	value		bigint unsigned		DEFAULT '0'	NOT NULL
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX history_uint_1 on history_uint (itemid,clock);
 CREATE TABLE history_uint_sync (
 	id		bigint unsigned			NOT NULL	auto_increment unique,
@@ -205,13 +205,13 @@ CREATE TABLE history_uint_sync (
 	clock		integer		DEFAULT '0'	NOT NULL,
 	value		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (id)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX history_uint_sync_1 on history_uint_sync (nodeid,id);
 CREATE TABLE history_str (
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	clock		integer		DEFAULT '0'	NOT NULL,
 	value		varchar(255)		DEFAULT ''	NOT NULL
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX history_str_1 on history_str (itemid,clock);
 CREATE TABLE history_str_sync (
 	id		bigint unsigned			NOT NULL	auto_increment unique,
@@ -220,7 +220,7 @@ CREATE TABLE history_str_sync (
 	clock		integer		DEFAULT '0'	NOT NULL,
 	value		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (id)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX history_str_sync_1 on history_str_sync (nodeid,id);
 CREATE TABLE history_log (
 	id		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -232,7 +232,7 @@ CREATE TABLE history_log (
 	value		text			NOT NULL,
 	logeventid		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (id)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX history_log_1 on history_log (itemid,clock);
 CREATE UNIQUE INDEX history_log_2 on history_log (itemid,id);
 CREATE TABLE history_text (
@@ -241,7 +241,7 @@ CREATE TABLE history_text (
 	clock		integer		DEFAULT '0'	NOT NULL,
 	value		text			NOT NULL,
 	PRIMARY KEY (id)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX history_text_1 on history_text (itemid,clock);
 CREATE UNIQUE INDEX history_text_2 on history_text (itemid,id);
 CREATE TABLE proxy_history (
@@ -254,7 +254,7 @@ CREATE TABLE proxy_history (
 	value		text			NOT NULL,
 	logeventid		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (id)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX proxy_history_1 on proxy_history (clock);
 CREATE TABLE proxy_dhistory (
 	id		bigint unsigned			NOT NULL	auto_increment unique,
@@ -268,7 +268,7 @@ CREATE TABLE proxy_dhistory (
 	status		integer		DEFAULT '0'	NOT NULL,
 	dcheckid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (id)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX proxy_dhistory_1 on proxy_dhistory (clock);
 CREATE TABLE events (
 	eventid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -279,7 +279,7 @@ CREATE TABLE events (
 	value		integer		DEFAULT '0'	NOT NULL,
 	acknowledged		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (eventid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX events_1 on events (object,objectid,eventid);
 CREATE INDEX events_2 on events (clock);
 CREATE TABLE trends (
@@ -290,7 +290,7 @@ CREATE TABLE trends (
 	value_avg		double(16,4)		DEFAULT '0.0000'	NOT NULL,
 	value_max		double(16,4)		DEFAULT '0.0000'	NOT NULL,
 	PRIMARY KEY (itemid,clock)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE trends_uint (
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	clock		integer		DEFAULT '0'	NOT NULL,
@@ -299,7 +299,7 @@ CREATE TABLE trends_uint (
 	value_avg		bigint unsigned		DEFAULT '0'	NOT NULL,
 	value_max		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (itemid,clock)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE acknowledges (
 	acknowledgeid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	userid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -307,7 +307,7 @@ CREATE TABLE acknowledges (
 	clock		integer		DEFAULT '0'	NOT NULL,
 	message		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (acknowledgeid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX acknowledges_1 on acknowledges (userid);
 CREATE INDEX acknowledges_2 on acknowledges (eventid);
 CREATE INDEX acknowledges_3 on acknowledges (clock);
@@ -322,7 +322,7 @@ CREATE TABLE auditlog (
 	resourceid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	resourcename		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (auditid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX auditlog_1 on auditlog (userid,clock);
 CREATE INDEX auditlog_2 on auditlog (clock);
 CREATE TABLE auditlog_details (
@@ -333,7 +333,7 @@ CREATE TABLE auditlog_details (
 	oldvalue		blob			NOT NULL,
 	newvalue		blob			NOT NULL,
 	PRIMARY KEY (auditdetailid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX auditlog_details_1 on auditlog_details (auditid);
 CREATE TABLE service_alarms (
 	servicealarmid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -341,7 +341,7 @@ CREATE TABLE service_alarms (
 	clock		integer		DEFAULT '0'	NOT NULL,
 	value		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (servicealarmid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX service_alarms_1 on service_alarms (serviceid,clock);
 CREATE INDEX service_alarms_2 on service_alarms (clock);
 CREATE TABLE actions (
@@ -357,7 +357,7 @@ CREATE TABLE actions (
 	r_shortdata		varchar(255)		DEFAULT ''	NOT NULL,
 	r_longdata		blob			NOT NULL,
 	PRIMARY KEY (actionid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX actions_1 on actions (eventsource,status);
 CREATE TABLE operations (
 	operationid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -373,7 +373,7 @@ CREATE TABLE operations (
 	default_msg		integer		DEFAULT '0'	NOT NULL,
 	evaltype		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (operationid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX operations_1 on operations (actionid);
 CREATE TABLE opconditions (
 	opconditionid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -382,14 +382,14 @@ CREATE TABLE opconditions (
 	operator		integer		DEFAULT '0'	NOT NULL,
 	value		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (opconditionid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX opconditions_1 on opconditions (operationid);
 CREATE TABLE opmediatypes (
 	opmediatypeid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	operationid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	mediatypeid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (opmediatypeid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE UNIQUE INDEX opmediatypes_1 on opmediatypes (operationid);
 CREATE TABLE escalations (
 	escalationid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -401,7 +401,7 @@ CREATE TABLE escalations (
 	esc_step		integer		DEFAULT '0'	NOT NULL,
 	status		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (escalationid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX escalations_1 on escalations (actionid,triggerid);
 CREATE INDEX escalations_2 on escalations (status,nextcheck);
 CREATE TABLE applications (
@@ -410,7 +410,7 @@ CREATE TABLE applications (
 	name		varchar(255)		DEFAULT ''	NOT NULL,
 	templateid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (applicationid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX applications_1 on applications (templateid);
 CREATE UNIQUE INDEX applications_2 on applications (hostid,name);
 CREATE TABLE conditions (
@@ -420,7 +420,7 @@ CREATE TABLE conditions (
 	operator		integer		DEFAULT '0'	NOT NULL,
 	value		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (conditionid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX conditions_1 on conditions (actionid);
 CREATE TABLE config (
 	configid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -446,7 +446,7 @@ CREATE TABLE config (
 	max_in_table		integer		DEFAULT '50'	NOT NULL,
 	search_limit		integer		DEFAULT '1000'	NOT NULL,
 	PRIMARY KEY (configid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE functions (
 	functionid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -455,7 +455,7 @@ CREATE TABLE functions (
 	function		varchar(12)		DEFAULT ''	NOT NULL,
 	parameter		varchar(255)		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (functionid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX functions_1 on functions (triggerid);
 CREATE INDEX functions_2 on functions (itemid,function,parameter);
 CREATE TABLE graphs (
@@ -478,7 +478,7 @@ CREATE TABLE graphs (
 	ymin_itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	ymax_itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (graphid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX graphs_graphs_1 on graphs (name);
 CREATE TABLE graphs_items (
 	gitemid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -492,7 +492,7 @@ CREATE TABLE graphs_items (
 	type		integer		DEFAULT '0'	NOT NULL,
 	periods_cnt		integer		DEFAULT '5'	NOT NULL,
 	PRIMARY KEY (gitemid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX graphs_items_1 on graphs_items (itemid);
 CREATE INDEX graphs_items_2 on graphs_items (graphid);
 CREATE TABLE graph_theme (
@@ -513,7 +513,7 @@ CREATE TABLE graph_theme (
 	gridview		integer		DEFAULT 1	NOT NULL,
 	legendview		integer		DEFAULT 1	NOT NULL,
 	PRIMARY KEY (graphthemeid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX graph_theme_1 on graph_theme (description);
 CREATE INDEX graph_theme_2 on graph_theme (theme);
 CREATE TABLE groups (
@@ -521,14 +521,14 @@ CREATE TABLE groups (
 	name		varchar(64)		DEFAULT ''	NOT NULL,
 	internal		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (groupid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX groups_1 on groups (name);
 CREATE TABLE help_items (
 	itemtype		integer		DEFAULT '0'	NOT NULL,
 	key_		varchar(255)		DEFAULT ''	NOT NULL,
 	description		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (itemtype,key_)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE hosts (
 	hostid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	proxy_hostid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -565,7 +565,7 @@ CREATE TABLE hosts (
 	ipmi_error		varchar(128)		DEFAULT ''	NOT NULL,
 	snmp_error		varchar(128)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (hostid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX hosts_1 on hosts (host);
 CREATE INDEX hosts_2 on hosts (status);
 CREATE INDEX hosts_3 on hosts (proxy_hostid);
@@ -574,7 +574,7 @@ CREATE TABLE globalmacro (
 	macro		varchar(64)		DEFAULT ''	NOT NULL,
 	value		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (globalmacroid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX globalmacro_1 on globalmacro (macro);
 CREATE TABLE hostmacro (
 	hostmacroid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -582,14 +582,14 @@ CREATE TABLE hostmacro (
 	macro		varchar(64)		DEFAULT ''	NOT NULL,
 	value		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (hostmacroid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX hostmacro_1 on hostmacro (hostid,macro);
 CREATE TABLE hosts_groups (
 	hostgroupid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	hostid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	groupid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (hostgroupid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX hosts_groups_1 on hosts_groups (hostid,groupid);
 CREATE INDEX hosts_groups_2 on hosts_groups (groupid);
 CREATE TABLE hosts_profiles (
@@ -606,7 +606,7 @@ CREATE TABLE hosts_profiles (
 	location		blob			NOT NULL,
 	notes		blob			NOT NULL,
 	PRIMARY KEY (hostid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE hosts_profiles_ext (
 	hostid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	device_alias		varchar(64)		DEFAULT ''	NOT NULL,
@@ -668,13 +668,13 @@ CREATE TABLE hosts_profiles_ext (
 	poc_2_screen		varchar(64)		DEFAULT ''	NOT NULL,
 	poc_2_notes		blob			NOT NULL,
 	PRIMARY KEY (hostid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE hosts_templates (
 	hosttemplateid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	hostid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	templateid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (hosttemplateid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE UNIQUE INDEX hosts_templates_1 on hosts_templates (hostid,templateid);
 CREATE TABLE housekeeper (
 	housekeeperid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -682,14 +682,14 @@ CREATE TABLE housekeeper (
 	field		varchar(64)		DEFAULT ''	NOT NULL,
 	value		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (housekeeperid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE images (
 	imageid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	imagetype		integer		DEFAULT '0'	NOT NULL,
 	name		varchar(64)		DEFAULT '0'	NOT NULL,
 	image		longblob			NOT NULL,
 	PRIMARY KEY (imageid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX images_1 on images (imagetype,name);
 CREATE TABLE items (
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -734,7 +734,7 @@ CREATE TABLE items (
 	privatekey		varchar(64)		DEFAULT ''	NOT NULL,
 	mtime		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (itemid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE UNIQUE INDEX items_1 on items (hostid,key_);
 CREATE INDEX items_3 on items (status);
 CREATE INDEX items_4 on items (templateid);
@@ -743,7 +743,7 @@ CREATE TABLE items_applications (
 	applicationid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	itemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (itemappid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX items_applications_1 on items_applications (applicationid,itemid);
 CREATE INDEX items_applications_2 on items_applications (itemid);
 CREATE TABLE mappings (
@@ -752,7 +752,7 @@ CREATE TABLE mappings (
 	value		varchar(64)		DEFAULT ''	NOT NULL,
 	newvalue		varchar(64)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (mappingid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX mappings_1 on mappings (valuemapid);
 CREATE TABLE media (
 	mediaid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -763,7 +763,7 @@ CREATE TABLE media (
 	severity		integer		DEFAULT '63'	NOT NULL,
 	period		varchar(100)		DEFAULT '1-7,00:00-23:59'	NOT NULL,
 	PRIMARY KEY (mediaid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX media_1 on media (userid);
 CREATE INDEX media_2 on media (mediatypeid);
 CREATE TABLE media_type (
@@ -778,7 +778,7 @@ CREATE TABLE media_type (
 	username		varchar(255)		DEFAULT ''	NOT NULL,
 	passwd		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (mediatypeid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE profiles (
 	profileid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	userid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -790,7 +790,7 @@ CREATE TABLE profiles (
 	source		varchar(96)		DEFAULT ''	NOT NULL,
 	type		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (profileid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX profiles_1 on profiles (userid,idx,idx2);
 CREATE INDEX profiles_2 on profiles (userid,profileid);
 CREATE TABLE rights (
@@ -799,7 +799,7 @@ CREATE TABLE rights (
 	permission		integer		DEFAULT '0'	NOT NULL,
 	id		bigint unsigned			,
 	PRIMARY KEY (rightid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX rights_1 on rights (groupid);
 CREATE INDEX rights_2 on rights (id);
 CREATE TABLE scripts (
@@ -810,14 +810,14 @@ CREATE TABLE scripts (
 	usrgrpid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	groupid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (scriptid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE screens (
 	screenid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	name		varchar(255)		DEFAULT 'Screen'	NOT NULL,
 	hsize		integer		DEFAULT '1'	NOT NULL,
 	vsize		integer		DEFAULT '1'	NOT NULL,
 	PRIMARY KEY (screenid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE screens_items (
 	screenitemid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	screenid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -836,7 +836,7 @@ CREATE TABLE screens_items (
 	url		varchar(255)		DEFAULT ''	NOT NULL,
 	dynamic		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (screenitemid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE services (
 	serviceid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	name		varchar(128)		DEFAULT ''	NOT NULL,
@@ -847,7 +847,7 @@ CREATE TABLE services (
 	goodsla		double(16,4)		DEFAULT '99.9'	NOT NULL,
 	sortorder		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (serviceid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX services_1 on services (triggerid);
 CREATE TABLE services_links (
 	linkid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -855,7 +855,7 @@ CREATE TABLE services_links (
 	servicedownid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	soft		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (linkid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX services_links_links_1 on services_links (servicedownid);
 CREATE UNIQUE INDEX services_links_links_2 on services_links (serviceupid,servicedownid);
 CREATE TABLE sessions (
@@ -864,7 +864,7 @@ CREATE TABLE sessions (
 	lastaccess		integer		DEFAULT '0'	NOT NULL,
 	status		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (sessionid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX sessions_1 on sessions (userid, status);
 CREATE TABLE sysmaps_links (
 	linkid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -875,7 +875,7 @@ CREATE TABLE sysmaps_links (
 	color		varchar(6)		DEFAULT '000000'	NOT NULL,
 	label		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (linkid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE sysmaps_link_triggers (
 	linktriggerid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	linkid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -883,7 +883,7 @@ CREATE TABLE sysmaps_link_triggers (
 	drawtype		integer		DEFAULT '0'	NOT NULL,
 	color		varchar(6)		DEFAULT '000000'	NOT NULL,
 	PRIMARY KEY (linktriggerid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE UNIQUE INDEX sysmaps_link_triggers_1 on sysmaps_link_triggers (linkid,triggerid);
 CREATE TABLE sysmaps_elements (
 	selementid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -901,7 +901,7 @@ CREATE TABLE sysmaps_elements (
 	iconid_disabled		bigint unsigned		DEFAULT '0'	NOT NULL,
 	iconid_maintenance		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (selementid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE sysmaps (
 	sysmapid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	name		varchar(128)		DEFAULT ''	NOT NULL,
@@ -912,7 +912,7 @@ CREATE TABLE sysmaps (
 	label_location		integer		DEFAULT '0'	NOT NULL,
 	highlight		integer		DEFAULT '1'	NOT NULL,
 	PRIMARY KEY (sysmapid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX sysmaps_1 on sysmaps (name);
 CREATE TABLE triggers (
 	triggerid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -929,7 +929,7 @@ CREATE TABLE triggers (
 	templateid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	type		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (triggerid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX triggers_1 on triggers (status);
 CREATE INDEX triggers_2 on triggers (value);
 CREATE TABLE trigger_depends (
@@ -937,7 +937,7 @@ CREATE TABLE trigger_depends (
 	triggerid_down		bigint unsigned		DEFAULT '0'	NOT NULL,
 	triggerid_up		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (triggerdepid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX trigger_depends_1 on trigger_depends (triggerid_down,triggerid_up);
 CREATE INDEX trigger_depends_2 on trigger_depends (triggerid_up);
 CREATE TABLE users (
@@ -958,7 +958,7 @@ CREATE TABLE users (
 	attempt_clock		integer		DEFAULT 0	NOT NULL,
 	rows_per_page		integer		DEFAULT 50	NOT NULL,
 	PRIMARY KEY (userid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX users_1 on users (alias);
 CREATE TABLE usrgrp (
 	usrgrpid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -968,20 +968,20 @@ CREATE TABLE usrgrp (
 	api_access		integer		DEFAULT '0'	NOT NULL,
 	debug_mode		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (usrgrpid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX usrgrp_1 on usrgrp (name);
 CREATE TABLE users_groups (
 	id		bigint unsigned		DEFAULT '0'	NOT NULL,
 	usrgrpid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	userid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (id)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX users_groups_1 on users_groups (usrgrpid,userid);
 CREATE TABLE valuemaps (
 	valuemapid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	name		varchar(64)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (valuemapid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX valuemaps_1 on valuemaps (name);
 CREATE TABLE maintenances (
 	maintenanceid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -991,28 +991,28 @@ CREATE TABLE maintenances (
 	active_since		integer		DEFAULT '0'	NOT NULL,
 	active_till		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (maintenanceid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX maintenances_1 on maintenances (active_since,active_till);
 CREATE TABLE maintenances_hosts (
 	maintenance_hostid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	maintenanceid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	hostid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (maintenance_hostid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX maintenances_hosts_1 on maintenances_hosts (maintenanceid,hostid);
 CREATE TABLE maintenances_groups (
 	maintenance_groupid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	maintenanceid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	groupid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (maintenance_groupid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX maintenances_groups_1 on maintenances_groups (maintenanceid,groupid);
 CREATE TABLE maintenances_windows (
 	maintenance_timeperiodid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	maintenanceid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	timeperiodid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (maintenance_timeperiodid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX maintenances_windows_1 on maintenances_windows (maintenanceid,timeperiodid);
 CREATE TABLE timeperiods (
 	timeperiodid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -1025,13 +1025,13 @@ CREATE TABLE timeperiods (
 	period		integer		DEFAULT '0'	NOT NULL,
 	start_date		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (timeperiodid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE TABLE regexps (
 	regexpid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	name		varchar(128)		DEFAULT ''	NOT NULL,
 	test_string		blob			NOT NULL,
 	PRIMARY KEY (regexpid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX regexps_1 on regexps (name);
 CREATE TABLE user_history (
 	userhistoryid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -1047,7 +1047,7 @@ CREATE TABLE user_history (
 	title5		varchar(255)		DEFAULT ''	NOT NULL,
 	url5		varchar(255)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (userhistoryid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE UNIQUE INDEX user_history_1 on user_history (userid);
 CREATE TABLE expressions (
 	expressionid		bigint unsigned		DEFAULT '0'	NOT NULL,
@@ -1057,19 +1057,19 @@ CREATE TABLE expressions (
 	exp_delimiter		varchar(1)		DEFAULT ''	NOT NULL,
 	case_sensitive		integer		DEFAULT '0'	NOT NULL,
 	PRIMARY KEY (expressionid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX expressions_1 on expressions (regexpid);
 CREATE TABLE autoreg_host (
 	autoreg_hostid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	proxy_hostid		bigint unsigned		DEFAULT '0'	NOT NULL,
 	host		varchar(64)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (autoreg_hostid)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE UNIQUE INDEX autoreg_host_1 on autoreg_host (proxy_hostid,host);
 CREATE TABLE proxy_autoreg_host (
 	id		bigint unsigned			NOT NULL	auto_increment unique,
 	clock		integer		DEFAULT '0'	NOT NULL,
 	host		varchar(64)		DEFAULT ''	NOT NULL,
 	PRIMARY KEY (id)
-) type=InnoDB;
+) ENGINE=InnoDB;
 CREATE INDEX proxy_autoreg_host_1 on proxy_autoreg_host (clock);
